/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.parser
 * File:    ArgumentParser.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.parser;

import com.martiansoftware.jsap.FlaggedOption;
import com.martiansoftware.jsap.JSAP;
import com.martiansoftware.jsap.JSAPException;
import com.martiansoftware.jsap.JSAPResult;
import com.martiansoftware.jsap.Switch;
import de.fhhannover.inform.iron.dhcp.control.Config;
/**
 * Parses the commandline-arguments sets the properties
 * @author Tobias
 *
 */
public class ArgumentParser {
	
	public static void start(String[] args) throws JSAPException{
		 JSAP jsap = new JSAP();
		 
		 Switch sw2 = new Switch("renew session")
         .setShortFlag('r')
         .setLongFlag("renew-session");
		 sw2.setHelp("Use renewSession() or not");
		 
		 FlaggedOption opt11 = new FlaggedOption("renew session intervall")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)        
         .setLongFlag("ri");
		 opt11.setHelp("Sets the intervall of renewSession()");
		 
		 FlaggedOption opt10 = new FlaggedOption("parser intervall")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setShortFlag('p')
         .setLongFlag("parse-intervall");
		 opt10.setHelp("Sets the intervall for the parser");
		 				 
		 FlaggedOption opt1 = new FlaggedOption("url")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setShortFlag('u')
         .setLongFlag("url");
		 opt1.setHelp("Sets the URL of the MAP-Server");
		 
		 FlaggedOption opt2 = new FlaggedOption("keystore")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setShortFlag('k')
         .setLongFlag("keystore");
		 opt2.setHelp("Sets the Keystore-File");
		 
		 FlaggedOption opt3 = new FlaggedOption("truststore")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setShortFlag('t')
         .setLongFlag("truststore");
		 opt3.setHelp("Sets the Truststore-File");
		 
		 
		 FlaggedOption opt4 = new FlaggedOption("keystore password")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("kp");
		 opt4.setHelp("Sets the Keystore password");
		 
		 FlaggedOption opt5 = new FlaggedOption("truststore password")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("ts");
		 opt5.setHelp("Sets the Truststore password");
		 
		 Switch sw = new Switch("basic-auth")
         .setShortFlag('b')
         .setLongFlag("basic-auth");
		 sw.setHelp("Use Basic-Authentification or not");

		 
		 FlaggedOption opt6 = new FlaggedOption("basic auth user")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("bu");
		 opt6.setHelp("Sets the username for Basic-Authentification");
		 
		 FlaggedOption opt7 = new FlaggedOption("basic auth password")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("bp");
		 opt7.setHelp("Sets the password for Basic-Authentification");
		 

		 FlaggedOption opt8 = new FlaggedOption("dhcpd leases path")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("leases");
		 opt8.setHelp("Sets the file with leases");
		 

		 FlaggedOption opt9 = new FlaggedOption("dhcpd server ip")
         .setStringParser(JSAP.STRING_PARSER)          
         .setRequired(false)
         .setLongFlag("ds");
		 opt9.setHelp("Sets the ip of the dhcpd");
		 
		 
		 jsap.registerParameter(opt1);
		 jsap.registerParameter(opt2);
		 jsap.registerParameter(opt3);
		 jsap.registerParameter(opt4);
		 jsap.registerParameter(opt5);
		 jsap.registerParameter(opt6);
		 jsap.registerParameter(opt7);
		 jsap.registerParameter(opt8);
		 jsap.registerParameter(opt9);
		 jsap.registerParameter(sw);
		 
		 JSAPResult conf = jsap.parse(args);    

	     if (!conf.success()) {
	            System.err.println();
	            System.err.println("Usage: java -jar mapdhcp-1.0.jar");
	            System.err.println("                "+ jsap.getUsage());
	            System.err.println();	           
	            System.err.println(jsap.getHelp());
	            System.exit(1);
	     }        
	     fillConfig(conf);
	}
	
	/**
	 * Fills the properties with commandline values
	 * @param conf
	 */
	private static void fillConfig(JSAPResult conf){
		if(conf.contains("parser intervall"))
			Config.MAPDHCP_PARSER_INTERVALL = conf.getInt("parser intervall");
		if(conf.contains("renew session"))
			Config.MAPDHCP_RENEWSESSION_ENABLED = conf.getBoolean("renew session");
		if(conf.contains("renew session intervall"))
			Config.MAPDHCP_RENEWSESSION_INTERVALL = conf.getInt("renew session intervall");
		if(conf.contains("url"))
			Config.MAPSERVER_URL = conf.getString("url");
		if(conf.contains("keystore"))
			Config.MAPSERVER_KEYSTORE_PATH = conf.getString("keystore");
		if(conf.contains("keystore password"))
			Config.MAPSERVER_KEYSTORE_PASSWORD = conf.getString("keystore password");
		if(conf.contains("truststore"))
			Config.MAPSERVER_TRUSTSTORE_PATH = conf.getString("truststore");
		if(conf.contains("truststore password"))
			Config.MAPSERVER_TRUSTSTORE_PASSWORD = conf.getString("truststore password");
		if(conf.contains("basic auth"))
			Config.MAPSERVER_BASICAUTH_ENABLED = conf.getBoolean("basic auth");
		if(conf.contains("basic auth user"))
			Config.MAPSERVER_BASICAUTH_USER = conf.getString("basic auth user");
		if(conf.contains("basic auth password"))
			Config.MAPSERVER_BASICAUTH_PASSWORD = conf.getString("basic auth password");
		if(conf.contains("dhcp server ip"))
			Config.DHCPD_SERVER_IP = conf.getString("dhcp server ip");
		if(conf.contains("dhcp leases path"))
			Config.DHCPD_LEASES_PATH = conf.getString("dhcp leases path");
		if(conf.contains("dhcp config path"))
			Config.DHCPD_CONFIG_PATH = conf.getString("dhcp config path");		
	}
}
