/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.soap
 * File:    LeaseMessage.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.soap;

import java.util.Calendar;

/**
 * This EntityClass represents a Lease Object.
 * It contains all information that should be send to the IF-MAP Server.
 *
 * @version 	0.01 24 Nov 2009
 * @version 	0.02 15 Dez 2009
 * @version	    0.03 17 Mar 2010
 * @version	    0.04 11 May 2010
 * @version	    0.05 16 June 2010
 * @author 	Sebastian Kobert
 */
public class LeaseMessage {
	
	/** mIp represents the IP-Adress that belongs to the Lease */
	private String mIp;
	
	/** mMac represents the MAC-Adress that belongs to the Lease */
	private String mMac;
	
	/** mStartDate represents the start Date of the Lease */
	private Calendar mStartDate;
	
	/** mEndDate represents the end Date of the Lease */
	private Calendar mEndDate;
	
	/** mMessageType represents the Type of the Lease Message */
	private int mMessageType;
	
	/** UPDATE_MESSAGE represents the Type publishUpdate */
	public static final int UPDATE_MESSAGE = 0;
	
	/** DELETE_MESSAGE represents the Type publishDelete */
	public static final int DELETE_MESSAGE = 1;

	/**
	 * @param messageType the Type of the Lease Message
	 * @param ip the IP-Adresse of the Lease
	 * @param mac the MAC-Adresse of the Lease
	 * @param startDate the start Date of the Lease
	 * @param endDate the end Date of the Lease
	 * @param options the DHCP-Options of the Lease
	 */
	public LeaseMessage(int messageType, String ip, String mac, Calendar startDate, Calendar endDate) {
		super();
		this.mMessageType = messageType;
		this.mIp = ip;
		this.mMac = mac;
		this.mStartDate = startDate;
		this.mEndDate = endDate;		
	}

	/**
	 * @return the ip
	 */
	public String getIp() {
		return mIp;
	}

	/**
	 * @param ip the ip to set
	 */
	public void setIp(String ip) {
		this.mIp = ip;
	}

	/**
	 * @return the mac
	 */
	public String getMac() {
		return mMac;
	}

	/**
	 * @param mac the mac to set
	 */
	public void setMac(String mac) {
		this.mMac = mac;
	}

	/**
	 * @return the start Date of the Lease
	 */
	public Calendar getStartDate() {
		return mStartDate;
	}

	/**
	 * @param startDate the start to set
	 */
	public void setStartDate(Calendar startDate) {
		this.mStartDate = startDate;
	}

	/**
	 * @return the end Date of the Lease
	 */
	public Calendar getEndDate() {
		return mEndDate;
	}

	/**
	 * @param endDate the end to set
	 */
	public void setEndDate(Calendar endDate) {
		this.mEndDate = endDate;
	}

	/**
	 * @return the MessageType of the Lease Message
	 */
	public int getMessageType() {
		return mMessageType;
	}	
}
